Module socket
hanzo_
quant
0.6.1
Module socket
Module Items
Structs
In hanzo_
quant::
distributed
hanzo_quant
::
distributed
Module
socket
Structs

Client
The Client holds its persistent connection inside a Mutex so that its barrier operations can have mutable access to the stream.
Server
The Server maintains persistent connections.