pub struct FP8Linear { /* private fields */ }Trait Implementations
Sourceimpl QuantMethod for FP8Linear
impl QuantMethod for FP8Linear
fn new(method: QuantMethodConfig) -> Result<Self>where
Self: Sized,
fn dequantize_w(&self) -> Result<Tensor>
Sourcefn forward_raw(&self, x: &Tensor) -> Result<Tensor>
fn forward_raw(&self, x: &Tensor) -> Result<Tensor>
Raw matmul without dtype casting. Implementors override this.
Callers should use
forward instead.Sourcefn quantized_act_type(&self) -> Option<DType>
fn quantized_act_type(&self) -> Option<DType>
If a quantized method, return the activation dtype.
Sourcefn add_delta_w(&self, delta: &Tensor) -> Result<Arc<dyn QuantMethod>>
fn add_delta_w(&self, delta: &Tensor) -> Result<Arc<dyn QuantMethod>>
Add a delta weight from LoRA to the weights. This should be prescaled with alpha.
Sourcefn dtype_and_device(&self) -> (DType, Device)
fn dtype_and_device(&self) -> (DType, Device)
Weight dtype and device
Sourcefn apply_isq(
self: Arc<Self>,
dtype: Option<IsqType>,
device: Device,
_n_quantized: &AtomicUsize,
_imatrix_weight: Option<Vec<f32>>,
guard: QuantizeOntoGuard,
) -> Result<Arc<dyn QuantMethod>>
fn apply_isq( self: Arc<Self>, dtype: Option<IsqType>, device: Device, _n_quantized: &AtomicUsize, _imatrix_weight: Option<Vec<f32>>, guard: QuantizeOntoGuard, ) -> Result<Arc<dyn QuantMethod>>
If the quant is backed by a qmatmul.
Sourcefn forward(&self, a: &Tensor) -> Result<Tensor>
fn forward(&self, a: &Tensor) -> Result<Tensor>
Compute matmul of
self and a. self should contain the weights.
Automatically casts to the required quantization activation type and back.Sourcefn gather_forward(&self, a: &Tensor, indices: &Tensor) -> Result<Tensor>
fn gather_forward(&self, a: &Tensor, indices: &Tensor) -> Result<Tensor>
Compute gather matmul of
self and a. self should contain the weights.
Automatically casts to the required quantization activation type and back. Read moreSourcefn gather_forward_raw(&self, _a: &Tensor, _indices: &Tensor) -> Result<Tensor>
fn gather_forward_raw(&self, _a: &Tensor, _indices: &Tensor) -> Result<Tensor>
Raw gather matmul without dtype casting. Implementors override this.
Callers should use
gather_forward instead.Sourcefn afq_inner(&self) -> Option<AfqInner<'_>>
fn afq_inner(&self) -> Option<AfqInner<'_>>
If this is an AFQ layer, return its (w_q, scales, biases, bits, group_size).
Used by Metal fused QKV / gate-up paths.
fn unquant_weight_bias(&self) -> Option<(Tensor, Option<Tensor>)>
fn has_bias(&self) -> bool
Sourcefn begin_track_stats(&mut self) -> Result<()>
fn begin_track_stats(&mut self) -> Result<()>
Begin tracking stats into an ImatrixLayerStats
Sourcefn end_track_stats(&self) -> Result<Tensor>
fn end_track_stats(&self) -> Result<Tensor>
End tracking stats into an ImatrixLayerStats. Returns the computed imatrix.
fn is_distributed(&self) -> Option<DistributedKind>
fn dummy_info(&self) -> Option<&DummyLayerInfo>
Sourceimpl QuantizedSerde for FP8Linear
impl QuantizedSerde for FP8Linear
fn isq_serde_supported(&self) -> bool
fn name(&self) -> &'static str
fn serialize(&self) -> Result<Cow<'_, [u8]>>
Sourcefn serialize_with_bias(&self, bias: Option<Tensor>) -> Result<Cow<'_, [u8]>>
fn serialize_with_bias(&self, bias: Option<Tensor>) -> Result<Cow<'_, [u8]>>
NOT meant for external calling
fn deserialize(
data: Cow<'_, [u8]>,
device: &Device,
_comm: &Arc<Comm>,
guard: QuantizeOntoGuard,
) -> Result<Arc<dyn QuantMethod>>where
Self: Sized,
fn deserialize_ext_bias(
data: Cow<'_, [u8]>,
device: &Device,
guard: QuantizeOntoGuard,
) -> Result<(Arc<dyn QuantMethod>, Option<Tensor>)>where
Self: Sized,